@@ -19,10 +19,7 @@
 """Signal class for Luminescence spectral data (1D).
 """
 import numpy as np
-from inspect import getfullargspec
 from warnings import warn
-from textwrap import indent
-
 
 from hyperspy.signals import Signal1D
 from hyperspy._signals.lazy import LazySignal
@@ -30,6 +27,7 @@ from hyperspy.axes import DataAxis
 
 from lumispy.signals.common_luminescence import CommonLumi
 from lumispy import nm2invcm, to_array, savetxt
+from lumispy.utils.axes import GRATING_EQUATION_DOCSTRING_PARAMETERS
 from lumispy.utils import (
     axis2eV,
     data2eV,
@@ -38,7 +36,6 @@ from lumispy.utils import (
     data2invcm,
     var2invcm,
     solve_grating_equation,
-    GRATING_EQUATION_DOCSTRING_PARAMETERS,
 )
 from lumispy.utils.io import (
     SAVETXT_DOCSTRING,
@@ -98,8 +95,8 @@ class LumiSpectrum(Signal1D, CommonLumi):
 
     def to_eV(self, inplace=True, jacobian=True):
         """Converts signal axis of 1D signal to non-linear energy axis (eV)
-        using wavelength dependent permittivity of air. Assumes wavelength in
-        units of nm unless the axis units are specifically set to µm.
+        using wavelength dependent refractive index of air. Assumes wavelength
+        in units of nm unless the axis units are specifically set to µm.
 
         The intensity is converted from counts/nm (counts/µm) to counts/meV by
         doing a Jacobian transformation, see e.g. Mooney and Kambhampati, J.
@@ -191,14 +188,16 @@ class LumiSpectrum(Signal1D, CommonLumi):
         else:
             # create new data array
             if jacobian:
-                s2data = data2eV(
-                    self.isig[::-1].data,
-                    factor,
-                    self.axes_manager.signal_axes[0],
-                    evaxis.axis,
+                s2data = np.copy(
+                    data2eV(
+                        self.isig[::-1].data,
+                        factor,
+                        self.axes_manager.signal_axes[0],
+                        evaxis.axis,
+                    )
                 )
             else:
-                s2data = self.isig[::-1].data
+                s2data = np.copy(self.isig[::-1].data)
 
             # create new signal object with correct data, axes, metadata
             s2 = self._deepcopy_with_new_data(
@@ -213,14 +212,11 @@ class LumiSpectrum(Signal1D, CommonLumi):
                 if jacobian:
                     # if variance is a numeric value, cast into signal object
                     if isinstance(var, (float, int)):
-                        self.set_noise_variance(
-                            self._deepcopy_with_new_data(
-                                np.ones(self.data.shape) * var,
-                                copy_variance=False,
-                                copy_learning_results=False,
-                            )
+                        var = self._deepcopy_with_new_data(
+                            np.ones(self.data.shape) * var,
+                            copy_variance=False,
+                            copy_learning_results=False,
                         )
-                        var = self.get_noise_variance()
                     # convert
                     s2var = s2._deepcopy_with_new_data(
                         var2eV(
@@ -251,7 +247,7 @@ class LumiSpectrum(Signal1D, CommonLumi):
         The intensity is converted from counts/nm (counts/µm) to counts/cm^-1
         by doing a Jacobian transformation, see e.g. Mooney and Kambhampati,
         J. Phys. Chem. Lett. 4, 3316 (2013), doi:10.1021/jz401508t, which
-        ensures that integrated signals are correct also in the wavenumber 
+        ensures that integrated signals are correct also in the wavenumber
         domain. If the variance of the signal is known, i.e.
         `metadata.Signal.Noise_properties.variance` is a signal representing the
         variance, a squared renormalization of the variance is performed.
@@ -263,10 +259,6 @@ class LumiSpectrum(Signal1D, CommonLumi):
         inplace : boolean
             If `False`, a new signal object is created and returned. Otherwise
             (default) the operation is performed on the existing signal object.
-        jacobian : boolean
-            The default is to do the Jacobian transformation (recommended at
-            least for luminescence signals), but the transformation can be
-            suppressed by setting this option to `False`.
         """
 
     TO_INVCM_EXAMPLE = """
@@ -283,6 +275,10 @@ class LumiSpectrum(Signal1D, CommonLumi):
         (cm^-1). Assumes wavelength in units of nm unless the axis units are
         specifically set to µm.
         %s
+        jacobian : boolean
+            The default is to do the Jacobian transformation (recommended at
+            least for luminescence signals), but the transformation can be
+            suppressed by setting this option to `False`.
         %s
         """
 
@@ -346,13 +342,15 @@ class LumiSpectrum(Signal1D, CommonLumi):
         else:
             # create new data array
             if jacobian:
-                s2data = data2invcm(
-                    self.isig[::-1].data,
-                    factor,
-                    invcmaxis.axis,
+                s2data = np.copy(
+                    data2invcm(
+                        self.isig[::-1].data,
+                        factor,
+                        invcmaxis.axis,
+                    )
                 )
             else:
-                s2data = self.isig[::-1].data
+                s2data = np.copy(self.isig[::-1].data)
 
             # create new signal object with correct data, axes, metadata
             s2 = self._deepcopy_with_new_data(
@@ -367,14 +365,11 @@ class LumiSpectrum(Signal1D, CommonLumi):
                 if jacobian:
                     # if variance is a numeric value, cast into signal object
                     if isinstance(var, (float, int)):
-                        self.set_noise_variance(
-                            self._deepcopy_with_new_data(
-                                np.ones(self.data.shape) * var,
-                                copy_variance=False,
-                                copy_learning_results=False,
-                            )
+                        var = self._deepcopy_with_new_data(
+                            np.ones(self.data.shape) * var,
+                            copy_variance=False,
+                            copy_learning_results=False,
                         )
-                        var = self.get_noise_variance()
                     s2var = s2._deepcopy_with_new_data(
                         var2invcm(
                             var.isig[::-1].data,
@@ -409,9 +404,9 @@ class LumiSpectrum(Signal1D, CommonLumi):
         >>> S1.to_invcm(laser=325)
     """
 
-    def to_invcm_relative(self, laser=None, inplace=True, jacobian=True):
+    def to_invcm_relative(self, laser=None, inplace=True, jacobian=False):
         """Converts signal axis of 1D signal to non-linear wavenumber axis
-        (cm^-1) relative to the exciting laser wavelength (Stokes/Anti-Stokes
+        (cm^-1) relative to the exciting laser wavelength (Raman/Stokes
         shift). Assumes wavelength in units of nm unless the axis units are
         specifically set to µm.
         %s
@@ -419,11 +414,15 @@ class LumiSpectrum(Signal1D, CommonLumi):
             Laser wavelength in the same units as the signal axis. If None
             (default), checks if it is stored in
             `metadata.Acquisition_instrument.Laser.wavelength`.
+        jacobian : boolean
+            The default is not to do the Jacobian transformation for Raman
+            shifts, but the transformation can be activated by setting this
+            option to `True`.
         %s
         """
 
         # check if laser wavelength is available
-        if laser == None:
+        if laser is None:
             if not self.metadata.has_item("Acquisition_instrument.Laser.wavelength"):
                 raise AttributeError(
                     "Laser wavelength is neither given in the metadata nor passed"
@@ -450,6 +449,7 @@ class LumiSpectrum(Signal1D, CommonLumi):
             invcmlaser = nm2invcm(laser)
         absaxis = invcmaxis.axis[::-1]
         invcmaxis.axis = invcmlaser - absaxis
+        invcmaxis.name = "Raman Shift"
 
         # replace signal axis after conversion
         # in place conversion (using absolute scale for Jacobian)
@@ -458,6 +458,7 @@ class LumiSpectrum(Signal1D, CommonLumi):
             self.axes_manager.set_axis(
                 invcmaxis, self.axes_manager.signal_axes[0].index_in_axes_manager
             )
+            self.data = self.isig[::-1].data
             # replace variance axis
             if self.metadata.has_item(
                 "Signal.Noise_properties.variance"
@@ -465,12 +466,16 @@ class LumiSpectrum(Signal1D, CommonLumi):
                 self.metadata.Signal.Noise_properties.variance.axes_manager.set_axis(
                     invcmaxis, self.axes_manager.signal_axes[0].index_in_axes_manager
                 )
+                self.metadata.Signal.Noise_properties.variance.data = (
+                    self.metadata.Signal.Noise_properties.variance.isig[::-1].data
+                )
         # create and return new signal
         else:
             s2 = self.to_invcm(inplace=inplace, jacobian=jacobian)
             s2.axes_manager.set_axis(
                 invcmaxis, self.axes_manager.signal_axes[0].index_in_axes_manager
             )
+            s2.data = s2.isig[::-1].data
             # replace variance axis
             if s2.metadata.has_item(
                 "Signal.Noise_properties.variance"
@@ -478,6 +483,9 @@ class LumiSpectrum(Signal1D, CommonLumi):
                 s2.metadata.Signal.Noise_properties.variance.axes_manager.set_axis(
                     invcmaxis, s2.axes_manager.signal_axes[0].index_in_axes_manager
                 )
+                s2.metadata.Signal.Noise_properties.variance.data = (
+                    s2.metadata.Signal.Noise_properties.variance.isig[::-1].data
+                )
             return s2
 
     to_invcm_relative.__doc__ %= (TO_INVCM_DOCSTRING, TO_INVCMREL_EXAMPLE)
@@ -525,7 +533,7 @@ class LumiSpectrum(Signal1D, CommonLumi):
                     "remove it again, set the "
                     "s.metadata.Signal.background_subtracted to False."
                 )
-        elif background is None:
+        elif background is None:  # pragma: no cover
             warn(
                 "Using the Hyperspy specfic `remove_background` function. "
                 "Use `s.remove_background()` instead.",
@@ -549,11 +557,7 @@ class LumiSpectrum(Signal1D, CommonLumi):
                 try:
                     bkg_x = background_xy[0]
                     bkg_y = background_xy[1]
-                    if len(bkg_x) is not len(bkg_y):
-                        raise AttributeError(
-                            "The length of the x and y axis must match."
-                        )
-                except IndexError:
+                except IndexError:  # pragma: no cover
                     raise AttributeError(
                         "Please provide a background file containing both the x and y axis."
                     )
@@ -721,5 +725,3 @@ class LazyLumiSpectrum(LazySignal, LumiSpectrum):
     """**General lazy 1D luminescence signal class.**"""
 
     _lazy = True
-
-    pass
