@@ -69,6 +69,21 @@ class TestCLSpectrum:
         np.testing.assert_almost_equal(s1.data[1, 0, 1], 1, decimal=5)
         np.testing.assert_almost_equal(s1.data[0, 2, 29], 1, decimal=5)
 
+        s3 = s.remove_spikes(show_diagnosis_histogram=True)
+        hist_data = s._spikes_diagnosis(
+            max_num_bins=25,
+            show_plot=False,
+            use_gui=False,
+        )
+        expected_data = np.zeros(25)
+        expected_data[0] = 176
+        expected_data[6] = 1
+        expected_data[12] = 2
+        expected_data[-1] = 1
+        np.testing.assert_allclose(hist_data.data, expected_data)
+        np.testing.assert_almost_equal(s3.data[1, 0, 1], 1, decimal=5)
+        np.testing.assert_almost_equal(s3.data[0, 2, 29], 1, decimal=5)
+
         lum_roi = [1, 1]
         s4 = s.remove_spikes(luminescence_roi=lum_roi, threshold=0.5)
         np.testing.assert_almost_equal(s4.data[1, 0, 1], 3, decimal=5)
