@@ -16,7 +16,6 @@
 # You should have received a copy of the GNU General Public License
 # along with LumiSpy. If not, see <https://www.gnu.org/licenses/#GPL>.
 
-from inspect import getfullargspec
 from numpy import arange, ones
 from numpy.testing import assert_allclose
 from pytest import raises, mark, skip, warns
@@ -97,6 +96,7 @@ def test_var2eV():
 def test_to_eV(jacobian, variance):
     axis = UniformDataAxis(size=20, offset=200, scale=10)
     data = ones(20)
+    data[0] += 1
     S1 = LumiSpectrum(data, axes=(axis.get_axis_dictionary(),))
     if variance:
         if variance == "constant":
@@ -106,13 +106,21 @@ def test_to_eV(jacobian, variance):
     S2 = S1.to_eV(inplace=False, jacobian=jacobian)
     S1.axes_manager[0].units = "µm"
     S1.axes_manager[0].axis = axis.axis / 1000
-    S1.data *= 1000
+    if jacobian:
+        S1.data *= 1000
     S1.to_eV(jacobian=jacobian)
     assert S1.axes_manager[0].units == "eV"
     assert S2.axes_manager[0].name == "Energy"
     assert S2.axes_manager[0].size == 20
     assert S1.axes_manager[0].axis[0] == S2.axes_manager[0].axis[0]
     assert_allclose(S1.data, S2.data, 5e-4)
+    if not jacobian:
+        S1.data *= 10  # check that deepcopy worked
+        assert S2.data[-1] == 2
+        assert S1.data[-1] == 20
+    else:
+        S1.data *= 10
+        assert_allclose(S2.data[-1], 0.06454526)
     nav = UniformDataAxis(size=4)
     # navigation dimension 1
     L1 = LumiSpectrum(
@@ -181,6 +189,12 @@ def test_to_eV(jacobian, variance):
         assert S1.metadata.has_item("Signal.Noise_properties.variance") == False
 
 
+def test_eV_slicing():
+    S = LumiSpectrum(arange(100), axes=[{"axis": arange(100) + 300}])
+    S.to_eV(inplace=True)
+    S.isig[3.251:4.052]
+
+
 @mark.parametrize(("jacobian"), (True, False))
 def test_reset_variance_linear_model_eV(jacobian):
     axis = UniformDataAxis(size=20, offset=200, scale=10)
@@ -277,6 +291,7 @@ def test_var2invcm():
 def test_to_invcm(jacobian, variance):
     axis = UniformDataAxis(size=20, offset=200, scale=10)
     data = ones(20)
+    data[0] += 1
     S1 = LumiSpectrum(data, axes=(axis.get_axis_dictionary(),))
     if variance:
         if variance == "constant":
@@ -286,13 +301,21 @@ def test_to_invcm(jacobian, variance):
     S2 = S1.to_invcm(inplace=False, jacobian=jacobian)
     S1.axes_manager[0].units = "µm"
     S1.axes_manager[0].axis = axis.axis / 1000
-    S1.data *= 1000
+    if jacobian:
+        S1.data *= 1000
     S1.to_invcm(jacobian=jacobian)
     assert S1.axes_manager[0].units == r"cm$^{-1}$"
     assert S2.axes_manager[0].name == "Wavenumber"
     assert S2.axes_manager[0].size == 20
     assert S1.axes_manager[0].axis[0] == S2.axes_manager[0].axis[0]
     assert_allclose(S1.data, S2.data, 5e-4)
+    if not jacobian:
+        S1.data *= 10  # check that deepcopy worked
+        assert S2.data[-1] == 2
+        assert S1.data[-1] == 20
+    else:
+        S1.data *= 10
+        assert S2.data[-1] == 0.008
     nav = UniformDataAxis(size=4)
     # navigation dimension 1
     L1 = LumiSpectrum(
@@ -361,6 +384,12 @@ def test_to_invcm(jacobian, variance):
         assert S1.metadata.has_item("Signal.Noise_properties.variance") == False
 
 
+def test_invcm_slicing():
+    S = LumiSpectrum(arange(100), axes=[{"axis": arange(100) + 300}])
+    S.to_invcm(inplace=True)
+    S.isig[26000.0:30000.0]
+
+
 @mark.parametrize(("jacobian"), (True, False))
 def test_reset_variance_linear_model_invcm(jacobian):
     axis = UniformDataAxis(size=20, offset=200, scale=10)
@@ -405,6 +434,7 @@ def test_reset_variance_linear_model_invcm(jacobian):
 def test_to_invcm_relative(jacobian, variance):
     axis = UniformDataAxis(size=20, offset=200, scale=10)
     data = ones(20)
+    data[0] += 1
     S1 = LumiSpectrum(data, axes=(axis.get_axis_dictionary(),))
     if variance:
         if variance == "constant":
@@ -414,10 +444,11 @@ def test_to_invcm_relative(jacobian, variance):
     S2 = S1.to_invcm_relative(laser=244, inplace=False, jacobian=jacobian)
     S1.axes_manager[0].units = "µm"
     S1.axes_manager[0].axis = axis.axis / 1000
-    S1.data *= 1000
+    if jacobian:
+        S1.data *= 1000
     S1.to_invcm_relative(laser=0.244, jacobian=jacobian)
     assert S1.axes_manager[0].units == r"cm$^{-1}$"
-    assert S2.axes_manager[0].name == "Wavenumber"
+    assert S2.axes_manager[0].name == "Raman Shift"
     assert S2.axes_manager[0].size == 20
     assert S1.axes_manager[0].axis[0] == S2.axes_manager[0].axis[0]
     assert_allclose(S1.data, S2.data, 5e-4)
@@ -434,7 +465,7 @@ def test_to_invcm_relative(jacobian, variance):
     L2 = L1.to_invcm_relative(laser=244, inplace=False, jacobian=jacobian)
     L1.to_invcm_relative(laser=244, jacobian=jacobian)
     assert L1.axes_manager.signal_axes[0].units == r"cm$^{-1}$"
-    assert L2.axes_manager.signal_axes[0].name == "Wavenumber"
+    assert L2.axes_manager.signal_axes[0].name == "Raman Shift"
     assert L2.axes_manager.signal_axes[0].size == 20
     assert (
         L1.axes_manager.signal_axes[0].axis[0] == L2.axes_manager.signal_axes[0].axis[0]
@@ -457,7 +488,7 @@ def test_to_invcm_relative(jacobian, variance):
     M2 = M1.to_invcm_relative(laser=244, inplace=False, jacobian=jacobian)
     M1.to_invcm_relative(laser=244, jacobian=jacobian)
     assert M1.axes_manager.signal_axes[0].units == r"cm$^{-1}$"
-    assert M2.axes_manager.signal_axes[0].name == "Wavenumber"
+    assert M2.axes_manager.signal_axes[0].name == "Raman Shift"
     assert M2.axes_manager.signal_axes[0].size == 20
     assert (
         M1.axes_manager.signal_axes[0].axis[0] == M2.axes_manager.signal_axes[0].axis[0]
@@ -493,17 +524,26 @@ def test_to_invcm_relative(jacobian, variance):
 def test_to_raman_shift(jacobian):
     axis = UniformDataAxis(size=20, offset=200, scale=10)
     data = ones(20)
+    data[0] += 1
     S1 = LumiSpectrum(data, axes=(axis.get_axis_dictionary(),))
     S2 = S1.to_raman_shift(laser=244, inplace=False, jacobian=jacobian)
     S1.axes_manager[0].units = "µm"
     S1.axes_manager[0].axis = axis.axis / 1000
-    S1.data *= 1000
+    if jacobian:
+        S1.data *= 1000
     S1.to_raman_shift(laser=0.244, jacobian=jacobian)
     assert S1.axes_manager[0].units == r"cm$^{-1}$"
-    assert S2.axes_manager[0].name == "Wavenumber"
+    assert S2.axes_manager[0].name == "Raman Shift"
     assert S2.axes_manager[0].size == 20
     assert S1.axes_manager[0].axis[0] == S2.axes_manager[0].axis[0]
     assert_allclose(S1.data, S2.data, 5e-4)
+    if not jacobian:
+        S1.data *= 10  # check that deepcopy worked
+        assert S2.data[0] == 2
+        assert S1.data[0] == 20
+    else:
+        S1.data *= 10
+        assert S2.data[0] == 0.008
 
 
 def test_to_raman_shift_laser():
@@ -518,37 +558,34 @@ def test_to_raman_shift_laser():
     S2 = S1.to_raman_shift(inplace=False)
     S1.axes_manager[0].units = "µm"
     S1.axes_manager[0].axis = axis.axis / 1000
-    S1.data *= 1000
     with raises(AttributeError, match="Laser wavelength units"):
         S1.to_raman_shift(laser=244)
     S1.metadata.set_item("Acquisition_instrument.Laser.wavelength", 0.244)
     S1.to_raman_shift()
     assert S1.axes_manager[0].units == r"cm$^{-1}$"
-    assert S2.axes_manager[0].name == "Wavenumber"
+    assert S2.axes_manager[0].name == "Raman Shift"
     assert S2.axes_manager[0].size == 20
     assert S1.axes_manager[0].axis[0] == S2.axes_manager[0].axis[0]
     assert_allclose(S1.data, S2.data, 5e-4)
 
 
+def test_ramanshift_slicing():
+    S = LumiSpectrum(arange(100), axes=[{"axis": arange(100) + 300}])
+    S.to_raman_shift(inplace=True, laser=295)
+    S.isig[3000.0:8000.0]
+
+
 def test_solve_grating_equation():
-    # Check which version of hyperspy is installed
-    if "scale" in getfullargspec(DataAxis)[0]:
-        axis_class = DataAxis
-    else:
-        from hyperspy.axes import UniformDataAxis
-
-        axis_class = UniformDataAxis
-
     with warns(SyntaxWarning, match="(not in pixel units)"):
-        axis = axis_class(size=20, offset=200, scale=10, units="nm")
+        axis = UniformDataAxis(size=20, offset=200, scale=10, units="nm")
         solve_grating_equation(axis, 3, -20, 300, 25, 600, 150)
 
-    axis1 = axis_class(
+    axis1 = UniformDataAxis(
         size=10,
         offset=200,
         scale=10,
     )
-    axis2 = axis_class(size=10, offset=200, scale=10, units="px")
+    axis2 = UniformDataAxis(size=10, offset=200, scale=10, units="px")
 
     nm_axis1 = solve_grating_equation(axis1, 3, -20, 300, 25, 600, 150)
     with warns(UserWarning, match="(range exceeds)"):
