@@ -15,7 +15,6 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with LumiSpy. If not, see <https://www.gnu.org/licenses/#GPL>.
-import warnings
 
 import numpy as np
 import scipy.constants as c
@@ -24,9 +23,7 @@ from inspect import getfullargspec
 from copy import deepcopy
 from warnings import warn
 
-from traits import traits
-
-from hyperspy.axes import *
+from hyperspy.axes import DataAxis, UniformDataAxis
 
 
 #
@@ -35,7 +32,7 @@ from hyperspy.axes import *
 
 
 def _n_air(x):
-    """Relative permittivity of air as a function of WL in nm.
+    """Refractive index of air as a function of WL in nm.
     This analytical function is correct for the range 185-1700 nm.
     According to `E.R. Peck and K. Reeder. Dispersion of air,
     J. Opt. Soc. Am. 62, 958-962 (1972).`
@@ -49,8 +46,8 @@ def _n_air(x):
             if wl > 1700:
                 wl = 1700
         else:
-            wl[wl < 185] = 185
-            wl[wl > 1700] = 1700
+            wl[wl < 185] = 185  # lgtm [py/modification-of-default-value]
+            wl[wl > 1700] = 1700  # lgtm [py/modification-of-default-value]
         warn(
             "The wavelength range exceeds the interval of 185 to 1700 nm for "
             "which the exact refractive index of air is used. Beyond this "
@@ -68,32 +65,32 @@ def _n_air(x):
 
 def nm2eV(x):
     """Converts wavelength (nm) to energy (eV) using wavelength-dependent
-    permittivity of air.
+    refractive index of air.
     """
     return 1e9 * c.h * c.c / (c.e * _n_air(x) * x)
 
 
 def eV2nm(x):
     """Converts energy (eV) to wavelength (nm) using wavelength-dependent
-    permittivity of air.
+    refractive index of air.
     """
-    wl = 1239.5 / x  # approximate WL to obtain permittivity
+    wl = 1239.5 / x  # approximate WL to obtain refractive index
     return 1e9 * c.h * c.c / (c.e * _n_air(wl) * x)
 
 
 def axis2eV(ax0):
     """Converts given signal axis to energy scale (eV) using wavelength
-    dependent permittivity of air. Assumes wavelength in units of nm unless the
+    dependent refractive index of air. Assumes wavelength in units of nm unless the
     axis units are specifically set to µm.
     """
     if ax0.units == "eV":
         raise AttributeError("Signal unit is already eV.")
     # transform axis, invert direction
     if ax0.units == "µm":
-        evaxis = nm2eV(1000 * ax0.axis)[::-1]
+        evaxis = nm2eV(1000 * ax0.axis)[::-1].astype("float")
         factor = 1e3  # correction factor for intensity
     else:
-        evaxis = nm2eV(ax0.axis)[::-1]
+        evaxis = nm2eV(ax0.axis)[::-1].astype("float")
         factor = 1e6
     axis = DataAxis(axis=evaxis, name="Energy", units="eV", navigate=False)
     return axis, factor
@@ -152,10 +149,10 @@ def axis2invcm(ax0):
         raise AttributeError(r"Signal unit is already cm$^{-1}$.")
     # transform axis, invert direction
     if ax0.units == "µm":
-        invcmaxis = nm2invcm(1000 * ax0.axis)[::-1]
+        invcmaxis = nm2invcm(1000 * ax0.axis)[::-1].astype("float")
         factor = 1e4  # correction factor for intensity
     else:
-        invcmaxis = nm2invcm(ax0.axis)[::-1]
+        invcmaxis = nm2invcm(ax0.axis)[::-1].astype("float")
         factor = 1e7
     axis = DataAxis(
         axis=invcmaxis, name="Wavenumber", units=r"cm$^{-1}$", navigate=False
@@ -360,10 +357,7 @@ def join_spectra(S, r=50, scale=True, average=False, kind="slinear"):
                     kind=kind,
                 )
                 length1 = axis.axis[ind1 - r : ind1 + 1].size
-                if length1 == 1:
-                    grad1 = 0
-                else:
-                    grad1 = 0.5 / (length1 - 1)
+                grad1 = 0.5 / (length1 - 1)
                 vect1 = np.arange(length1)
                 length2 = axis2.axis[ind2 : ind2 + r].size
                 if length2 == 1:
@@ -435,7 +429,7 @@ def solve_grating_equation(
     pixel_units = s in ["pixel", "px"]
 
     if not non_defined and not pixel_units:
-        warnings.warn(
+        warn(
             "The signal axes are already in {} units (not in pixel units)."
             "The conversion will run anyways.".format(str(axis.units)),
             SyntaxWarning,
@@ -484,10 +478,7 @@ def solve_grating_equation(
     # Create axis object to return
     scale = (l_max - l_min) / ch
 
-    if "scale" in getfullargspec(DataAxis)[0]:
-        axis_class = DataAxis
-    else:
-        axis_class = UniformDataAxis
+    axis_class = UniformDataAxis
 
     axis_nm = axis_class(
         scale=scale,
